@@ -1,6 +1,6 @@
 package DBIx::Class::DeploymentHandler::Dad;
 {
-  $DBIx::Class::DeploymentHandler::Dad::VERSION = '0.002115';
+  $DBIx::Class::DeploymentHandler::Dad::VERSION = '0.002200';
 }
 
 # ABSTRACT: Parent class for DeploymentHandlers
@@ -8,12 +8,8 @@ package DBIx::Class::DeploymentHandler::Dad;
 use Moose;
 require DBIx::Class::Schema;    # loaded for type constraint
 use Carp::Clan '^DBIx::Class::DeploymentHandler';
-use DBIx::Class::DeploymentHandler::Logger;
+use DBIx::Class::DeploymentHandler::LogImporter ':log';
 use DBIx::Class::DeploymentHandler::Types;
-use Log::Contextual ':log', -package_logger =>
-  DBIx::Class::DeploymentHandler::Logger->new({
-    env_prefix => 'DBICDH'
-  });
 
 has schema => (
   is       => 'ro',
